// ePDFView - A lightweight PDF Viewer.
// Copyright (C) 2006 Emma's Software.
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

#if !defined (__MAIN_PTER_H__)
#define __MAIN_PTER_H__

namespace ePDFView
{
    // Forward declarations.
    class IDocument;
    class DocumentPage;

    ///
    /// @class MainPter
    /// @brief Main window presenter.
    ///
    /// The presenter is the one responsible of the application's behaviour.
    ///
    /// This class will decide what the main window should show to the user
    /// and how to react to main window's user events.
    ///
    class MainPter
    {
        public:
            MainPter (void);
            MainPter (IDocument *document);
            ~MainPter (void);

            void setInitialState (gboolean canShowPage); 
            IMainView &getView (void);
            void setView (IMainView *view);
            
            void goToFirstPageActivated (void);
            void goToLastPageActivated (void);
            void goToNextPageActivated (void);
            void goToPageActivated (void);
            void goToPreviousPageActivated (void);
            void openDocument (const gchar *fileName, const gchar *oldPassword,
                               gboolean canShowPage);
            void openFileActivated (void);
            void outlineActivated (DocumentOutline *outline);
            void reloadActivated (void);
            void rotateLeftActivated (void);
            void rotateRightActivated (void);
            void zoomFitActivated (void);
            void zoomInActivated (void);
            void zoomOutActivated (void);
            void zoomWidthActivated (void);

        protected:
            void showPage (void);

            IDocument *m_Document;
            DocumentPage *m_DocumentPage;
            IMainView *m_View;
    };
}

#endif // !__MAIN_PTER_H__
