// ePDFView - A lightweight PDF Viewer.
// Copyright (C) 2006 Emma's Software.
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

#include <config.h>
#include <stdlib.h>
#include <gettext.h>
#include <locale.h>
#include <gtk/gtk.h>
#include <IMainView.h>
#include <MainView.h>
#include "MainPter.h"


using namespace ePDFView;

///
/// @brief The data passed to open_command_line_file() function.
///
typedef struct
{
    /// The presenter to make open the file.
    MainPter *presenter;
    /// The file name to open.
    gchar *fileName;
} OpenFileData;

// Forward declarations.
static gboolean open_command_line_file (gpointer data);

int
main (int argc, char **argv)
{
    // Enable NLS.
    setlocale (LC_ALL, "");
    bindtextdomain (PACKAGE, LOCALEDIR);
    bind_textdomain_codeset (PACKAGE, "UTF-8");
    textdomain (PACKAGE);
    // Create the command line options context.
    GOptionContext *optionContext = 
        g_option_context_new (_("[FILE] - view PDF documents"));
    g_option_context_add_group (optionContext, gtk_get_option_group (TRUE));
    GError *error = NULL;
    if ( !g_option_context_parse (optionContext, &argc, &argv, &error) )
    {
        g_critical ("Error parsing command line options: %s\n", error->message);
        g_error_free (error);
        exit (EXIT_FAILURE);
    }
    // Initialise the GTK library.
    gtk_init (&argc, &argv);
    g_set_application_name (_("PDF Viewer"));
    // Create the main presenter.
    MainPter *mainPter = new MainPter ();
    // Now check if we have additional parameters. Any additional parameter
    // will be a file name to open.
    if ( argc > 1 )
    {
        OpenFileData *openFile = new OpenFileData;
        if ( NULL != openFile )
        {
            openFile->presenter = mainPter;
            openFile->fileName = g_strdup (argv[1]);

            // This will call the function when no other GTK event is on
            // the queue, and will let the presenter open the file when
            // then main view is shown.
            g_idle_add (open_command_line_file, openFile);
        }
    }
    // Create the main view.
    MainView *mainView = new MainView (mainPter);
    // Let know to the presenter which is its view.
    mainPter->setView (mainView);
    // Enter the main loop and wait for user interaction. */
    gtk_main();
    
    // There's no need for us to delete the main view, as it's
    // the presenter's responsibility.
    delete mainPter;
    // All done!.
    return EXIT_SUCCESS;
}

gboolean
open_command_line_file (gpointer data)
{
    g_assert (NULL != data && "The data parameter is NULL.");

    OpenFileData *openFile = (OpenFileData *)data;
    g_assert (NULL != openFile->presenter && "The presenter is NULL.");
    g_assert (NULL != openFile->fileName && "The file name is NULL.");
    openFile->presenter->openDocument (openFile->fileName, NULL, TRUE);
    delete openFile;

    // Returning FALSE means that the function won't be called again.
    return FALSE;
}
